Welcome to ClientVPS Mirrors

Help for package ggplot2movies
Version: 0.0.1
Title: Movies Data
Description: A dataset about movies. This was previously contained in ggplot2, but has been moved its own package to reduce the download size of ggplot2.
Depends: R (≥ 2.10.0)
License: GPL-3
LazyData: true
NeedsCompilation: no
Packaged: 2015-08-25 13:37:51 UTC; hadley
Author: Hadley Wickham [aut, cre], RStudio [cph]
Maintainer: Hadley Wickham <hadley@rstudio.com>
Repository: CRAN
Date/Publication: 2015-08-25 16:05:24

Movie information and user ratings from IMDB.com.

Description

The internet movie database, http://imdb.com/, is a website devoted to collecting movie data supplied by studios and fans. It claims to be the biggest movie database on the web and is run by amazon. More about information imdb.com can be found online, http://imdb.com/help/show_leaf?about, including information about the data collection process, http://imdb.com/help/show_leaf?infosource.

Usage

movies

Format

A data frame with 28819 rows and 24 variables

Details

Movies were selected for inclusion if they had a known length and had been rated by at least one imdb user.

References

http://had.co.nz/data/movies/

Examples

dim(movies)
head(movies)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.